# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

# AutonML imports
import autonml.pipeline_pb2 as pipeline__pb2
import autonml.primitive_pb2 as primitive__pb2
import autonml.problem_pb2 as problem__pb2
import autonml.value_pb2 as value__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='core.proto',
  package='',
  syntax='proto3',
  serialized_options=b'Z\010pipeline\242\265\032\0051.0.0',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\ncore.proto\x1a google/protobuf/descriptor.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x0epipeline.proto\x1a\x0fprimitive.proto\x1a\rproblem.proto\x1a\x0bvalue.proto\"\x89\x01\n\x14ScoringConfiguration\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\r\n\x05\x66olds\x18\x02 \x01(\x05\x12\x18\n\x10train_test_ratio\x18\x03 \x01(\x01\x12\x0f\n\x07shuffle\x18\x04 \x01(\x08\x12\x13\n\x0brandom_seed\x18\x05 \x01(\x05\x12\x12\n\nstratified\x18\x06 \x01(\x08\"\x88\x01\n\x05Score\x12)\n\x06metric\x18\x01 \x01(\x0b\x32\x19.ProblemPerformanceMetric\x12\x0c\n\x04\x66old\x18\x02 \x01(\x05\x12\x15\n\x05value\x18\x04 \x01(\x0b\x32\x06.Value\x12\x13\n\x0brandom_seed\x18\x05 \x01(\x05\x12\x1a\n\nnormalized\x18\x06 \x01(\x0b\x32\x06.Value\"\x8d\x01\n\x08Progress\x12\x1d\n\x05state\x18\x01 \x01(\x0e\x32\x0e.ProgressState\x12\x0e\n\x06status\x18\x02 \x01(\t\x12)\n\x05start\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65nd\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x82\x03\n\x16SearchSolutionsRequest\x12\x12\n\nuser_agent\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x19\n\x11time_bound_search\x18\x03 \x01(\x01\x12\x10\n\x08priority\x18\x04 \x01(\x01\x12\x1b\n\x13\x61llowed_value_types\x18\x05 \x03(\t\x12$\n\x07problem\x18\x06 \x01(\x0b\x32\x13.ProblemDescription\x12&\n\x08template\x18\x07 \x01(\x0b\x32\x14.PipelineDescription\x12\x16\n\x06inputs\x18\x08 \x03(\x0b\x32\x06.Value\x12\x16\n\x0etime_bound_run\x18\t \x01(\x01\x12\x1c\n\x14rank_solutions_limit\x18\n \x01(\x05\x12\x13\n\x0brandom_seed\x18\x0b \x01(\x05\x12/\n\'use_default_values_for_free_hyperparams\x18\x0c \x01(\x08\x12\x17\n\x0fsearch_features\x18\r \x03(\t\",\n\x17SearchSolutionsResponse\x12\x11\n\tsearch_id\x18\x01 \x01(\t\".\n\x19\x45ndSearchSolutionsRequest\x12\x11\n\tsearch_id\x18\x01 \x01(\t\"\x1c\n\x1a\x45ndSearchSolutionsResponse\"/\n\x1aStopSearchSolutionsRequest\x12\x11\n\tsearch_id\x18\x01 \x01(\t\"\x1d\n\x1bStopSearchSolutionsResponse\"c\n\x13SolutionSearchScore\x12\x34\n\x15scoring_configuration\x18\x01 \x01(\x0b\x32\x15.ScoringConfiguration\x12\x16\n\x06scores\x18\x02 \x03(\x0b\x32\x06.Score\"5\n GetSearchSolutionsResultsRequest\x12\x11\n\tsearch_id\x18\x01 \x01(\t\"\xba\x01\n!GetSearchSolutionsResultsResponse\x12\x1b\n\x08progress\x18\x01 \x01(\x0b\x32\t.Progress\x12\x12\n\ndone_ticks\x18\x02 \x01(\x01\x12\x11\n\tall_ticks\x18\x03 \x01(\x01\x12\x13\n\x0bsolution_id\x18\x04 \x01(\t\x12\x16\n\x0einternal_score\x18\x05 \x01(\x01\x12$\n\x06scores\x18\x06 \x03(\x0b\x32\x14.SolutionSearchScore\".\n\x17\x44\x65scribeSolutionRequest\x12\x13\n\x0bsolution_id\x18\x01 \x01(\t\"\x97\x01\n\x18PrimitiveStepDescription\x12?\n\x0bhyperparams\x18\x01 \x03(\x0b\x32*.PrimitiveStepDescription.HyperparamsEntry\x1a:\n\x10HyperparamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x15\n\x05value\x18\x02 \x01(\x0b\x32\x06.Value:\x02\x38\x01\"=\n\x1aSubpipelineStepDescription\x12\x1f\n\x05steps\x18\x01 \x03(\x0b\x32\x10.StepDescription\"z\n\x0fStepDescription\x12.\n\tprimitive\x18\x01 \x01(\x0b\x32\x19.PrimitiveStepDescriptionH\x00\x12/\n\x08pipeline\x18\x02 \x01(\x0b\x32\x1b.SubpipelineStepDescriptionH\x00\x42\x06\n\x04step\"c\n\x18\x44\x65scribeSolutionResponse\x12&\n\x08pipeline\x18\x01 \x01(\x0b\x32\x14.PipelineDescription\x12\x1f\n\x05steps\x18\x02 \x03(\x0b\x32\x10.StepDescription\"I\n\x0cStepProgress\x12\x1b\n\x08progress\x18\x01 \x01(\x0b\x32\t.Progress\x12\x1c\n\x05steps\x18\x02 \x03(\x0b\x32\r.StepProgress\"=\n\x0fSolutionRunUser\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06\x63hosen\x18\x02 \x01(\x08\x12\x0e\n\x06reason\x18\x03 \x01(\t\"\xca\x01\n\x14ScoreSolutionRequest\x12\x13\n\x0bsolution_id\x18\x01 \x01(\t\x12\x16\n\x06inputs\x18\x02 \x03(\x0b\x32\x06.Value\x12\x36\n\x13performance_metrics\x18\x03 \x03(\x0b\x32\x19.ProblemPerformanceMetric\x12\x1f\n\x05users\x18\x04 \x03(\x0b\x32\x10.SolutionRunUser\x12,\n\rconfiguration\x18\x05 \x01(\x0b\x32\x15.ScoringConfiguration\"+\n\x15ScoreSolutionResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\"4\n\x1eGetScoreSolutionResultsRequest\x12\x12\n\nrequest_id\x18\x01 \x01(\t\"V\n\x1fGetScoreSolutionResultsResponse\x12\x1b\n\x08progress\x18\x01 \x01(\x0b\x32\t.Progress\x12\x16\n\x06scores\x18\x02 \x03(\x0b\x32\x06.Score\"\xab\x01\n\x12\x46itSolutionRequest\x12\x13\n\x0bsolution_id\x18\x01 \x01(\t\x12\x16\n\x06inputs\x18\x02 \x03(\x0b\x32\x06.Value\x12\x16\n\x0e\x65xpose_outputs\x18\x03 \x03(\t\x12\x1a\n\x12\x65xpose_value_types\x18\x04 \x03(\t\x12\x1f\n\x05users\x18\x05 \x03(\x0b\x32\x10.SolutionRunUser\x12\x13\n\x0brandom_seed\x18\x06 \x01(\x05\")\n\x13\x46itSolutionResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\"2\n\x1cGetFitSolutionResultsRequest\x12\x12\n\nrequest_id\x18\x01 \x01(\t\"\x82\x02\n\x1dGetFitSolutionResultsResponse\x12\x1b\n\x08progress\x18\x01 \x01(\x0b\x32\t.Progress\x12\x1c\n\x05steps\x18\x02 \x03(\x0b\x32\r.StepProgress\x12K\n\x0f\x65xposed_outputs\x18\x03 \x03(\x0b\x32\x32.GetFitSolutionResultsResponse.ExposedOutputsEntry\x12\x1a\n\x12\x66itted_solution_id\x18\x04 \x01(\t\x1a=\n\x13\x45xposedOutputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x15\n\x05value\x18\x02 \x01(\x0b\x32\x06.Value:\x02\x38\x01\"\xa1\x01\n\x16ProduceSolutionRequest\x12\x1a\n\x12\x66itted_solution_id\x18\x01 \x01(\t\x12\x16\n\x06inputs\x18\x02 \x03(\x0b\x32\x06.Value\x12\x16\n\x0e\x65xpose_outputs\x18\x03 \x03(\t\x12\x1a\n\x12\x65xpose_value_types\x18\x04 \x03(\t\x12\x1f\n\x05users\x18\x05 \x03(\x0b\x32\x10.SolutionRunUser\"-\n\x17ProduceSolutionResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\"6\n GetProduceSolutionResultsRequest\x12\x12\n\nrequest_id\x18\x01 \x01(\t\"\xee\x01\n!GetProduceSolutionResultsResponse\x12\x1b\n\x08progress\x18\x01 \x01(\x0b\x32\t.Progress\x12\x1c\n\x05steps\x18\x02 \x03(\x0b\x32\r.StepProgress\x12O\n\x0f\x65xposed_outputs\x18\x03 \x03(\x0b\x32\x36.GetProduceSolutionResultsResponse.ExposedOutputsEntry\x1a=\n\x13\x45xposedOutputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x15\n\x05value\x18\x02 \x01(\x0b\x32\x06.Value:\x02\x38\x01\":\n\x15SolutionExportRequest\x12\x13\n\x0bsolution_id\x18\x03 \x01(\t\x12\x0c\n\x04rank\x18\x02 \x01(\x01\"\x18\n\x16SolutionExportResponse\"w\n\x14\x44\x61taAvailableRequest\x12\x12\n\nuser_agent\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x12\n\ntime_bound\x18\x03 \x01(\x01\x12\x10\n\x08priority\x18\x04 \x01(\x01\x12\x14\n\x04\x64\x61ta\x18\x05 \x03(\x0b\x32\x06.Value\"\x17\n\x15\x44\x61taAvailableResponse\"\xa2\x01\n\x10SplitDataRequest\x12\x15\n\x05input\x18\x01 \x01(\x0b\x32\x06.Value\x12\x34\n\x15scoring_configuration\x18\x02 \x01(\x0b\x32\x15.ScoringConfiguration\x12\x1b\n\x13\x61llowed_value_types\x18\x03 \x03(\t\x12$\n\x07problem\x18\x04 \x01(\x0b\x32\x13.ProblemDescription\"l\n\x11SplitDataResponse\x12\x1c\n\x0ctrain_output\x18\x01 \x01(\x0b\x32\x06.Value\x12\x1b\n\x0btest_output\x18\x02 \x01(\x0b\x32\x06.Value\x12\x1c\n\x0cscore_output\x18\x03 \x01(\x0b\x32\x06.Value\"\xa4\x01\n\x17ScorePredictionsRequest\x12\x1b\n\x0bpredictions\x18\x01 \x01(\x0b\x32\x06.Value\x12\x1b\n\x0bscore_input\x18\x04 \x01(\x0b\x32\x06.Value\x12$\n\x07problem\x18\x02 \x01(\x0b\x32\x13.ProblemDescription\x12)\n\x06metric\x18\x03 \x03(\x0b\x32\x19.ProblemPerformanceMetric\"2\n\x18ScorePredictionsResponse\x12\x16\n\x06scores\x18\x01 \x03(\x0b\x32\x06.Score\"*\n\x13SaveSolutionRequest\x12\x13\n\x0bsolution_id\x18\x01 \x01(\t\",\n\x14SaveSolutionResponse\x12\x14\n\x0csolution_uri\x18\x01 \x01(\t\"+\n\x13LoadSolutionRequest\x12\x14\n\x0csolution_uri\x18\x01 \x01(\t\"+\n\x14LoadSolutionResponse\x12\x13\n\x0bsolution_id\x18\x01 \x01(\t\"7\n\x19SaveFittedSolutionRequest\x12\x1a\n\x12\x66itted_solution_id\x18\x01 \x01(\t\"9\n\x1aSaveFittedSolutionResponse\x12\x1b\n\x13\x66itted_solution_uri\x18\x01 \x01(\t\"8\n\x19LoadFittedSolutionRequest\x12\x1b\n\x13\x66itted_solution_uri\x18\x01 \x01(\t\"8\n\x1aLoadFittedSolutionResponse\x12\x1a\n\x12\x66itted_solution_id\x18\x01 \x01(\t\"\x17\n\x15ListPrimitivesRequest\"8\n\x16ListPrimitivesResponse\x12\x1e\n\nprimitives\x18\x01 \x03(\x0b\x32\n.Primitive\"\x0e\n\x0cHelloRequest\"\x80\x02\n\rHelloResponse\x12\x12\n\nuser_agent\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x1b\n\x13\x61llowed_value_types\x18\x03 \x03(\t\x12\x1c\n\x14supported_extensions\x18\x04 \x03(\t\x12\x1f\n\x17supported_task_keywords\x18\x05 \x03(\t\x12%\n\x1dsupported_performance_metrics\x18\x06 \x03(\t\x12$\n\x1csupported_evaluation_methods\x18\x07 \x03(\t\x12!\n\x19supported_search_features\x18\x08 \x03(\t*[\n\rProgressState\x12\x14\n\x10PROGRESS_UNKNOWN\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\r\n\tCOMPLETED\x10\x03\x12\x0b\n\x07\x45RRORED\x10\x04\x32\xab\x0c\n\x04\x43ore\x12\x46\n\x0fSearchSolutions\x12\x17.SearchSolutionsRequest\x1a\x18.SearchSolutionsResponse\"\x00\x12\x66\n\x19GetSearchSolutionsResults\x12!.GetSearchSolutionsResultsRequest\x1a\".GetSearchSolutionsResultsResponse\"\x00\x30\x01\x12O\n\x12\x45ndSearchSolutions\x12\x1a.EndSearchSolutionsRequest\x1a\x1b.EndSearchSolutionsResponse\"\x00\x12R\n\x13StopSearchSolutions\x12\x1b.StopSearchSolutionsRequest\x1a\x1c.StopSearchSolutionsResponse\"\x00\x12I\n\x10\x44\x65scribeSolution\x12\x18.DescribeSolutionRequest\x1a\x19.DescribeSolutionResponse\"\x00\x12@\n\rScoreSolution\x12\x15.ScoreSolutionRequest\x1a\x16.ScoreSolutionResponse\"\x00\x12`\n\x17GetScoreSolutionResults\x12\x1f.GetScoreSolutionResultsRequest\x1a .GetScoreSolutionResultsResponse\"\x00\x30\x01\x12:\n\x0b\x46itSolution\x12\x13.FitSolutionRequest\x1a\x14.FitSolutionResponse\"\x00\x12Z\n\x15GetFitSolutionResults\x12\x1d.GetFitSolutionResultsRequest\x1a\x1e.GetFitSolutionResultsResponse\"\x00\x30\x01\x12\x46\n\x0fProduceSolution\x12\x17.ProduceSolutionRequest\x1a\x18.ProduceSolutionResponse\"\x00\x12\x66\n\x19GetProduceSolutionResults\x12!.GetProduceSolutionResultsRequest\x1a\".GetProduceSolutionResultsResponse\"\x00\x30\x01\x12\x43\n\x0eSolutionExport\x12\x16.SolutionExportRequest\x1a\x17.SolutionExportResponse\"\x00\x12@\n\rDataAvailable\x12\x15.DataAvailableRequest\x1a\x16.DataAvailableResponse\"\x00\x12\x43\n\x0eListPrimitives\x12\x16.ListPrimitivesRequest\x1a\x17.ListPrimitivesResponse\"\x00\x12(\n\x05Hello\x12\r.HelloRequest\x1a\x0e.HelloResponse\"\x00\x12=\n\x0cSaveSolution\x12\x14.SaveSolutionRequest\x1a\x15.SaveSolutionResponse\"\x00\x12=\n\x0cLoadSolution\x12\x14.LoadSolutionRequest\x1a\x15.LoadSolutionResponse\"\x00\x12O\n\x12SaveFittedSolution\x12\x1a.SaveFittedSolutionRequest\x1a\x1b.SaveFittedSolutionResponse\"\x00\x12O\n\x12LoadFittedSolution\x12\x1a.LoadFittedSolutionRequest\x1a\x1b.LoadFittedSolutionResponse\"\x00\x12\x36\n\tSplitData\x12\x11.SplitDataRequest\x1a\x12.SplitDataResponse\"\x00\x30\x01\x12I\n\x10ScorePredictions\x12\x18.ScorePredictionsRequest\x1a\x19.ScorePredictionsResponse\"\x00:8\n\x10protocol_version\x12\x1c.google.protobuf.FileOptions\x18\xd4\xa6\x03 \x01(\tB\x13Z\x08pipeline\xa2\xb5\x1a\x05\x31.0.0b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,pipeline__pb2.DESCRIPTOR,primitive__pb2.DESCRIPTOR,problem__pb2.DESCRIPTOR,value__pb2.DESCRIPTOR,])

_PROGRESSSTATE = _descriptor.EnumDescriptor(
  name='ProgressState',
  full_name='ProgressState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PROGRESS_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPLETED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERRORED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5057,
  serialized_end=5148,
)
_sym_db.RegisterEnumDescriptor(_PROGRESSSTATE)

ProgressState = enum_type_wrapper.EnumTypeWrapper(_PROGRESSSTATE)
PROGRESS_UNKNOWN = 0
PENDING = 1
RUNNING = 2
COMPLETED = 3
ERRORED = 4

PROTOCOL_VERSION_FIELD_NUMBER = 54100
protocol_version = _descriptor.FieldDescriptor(
  name='protocol_version', full_name='protocol_version', index=0,
  number=54100, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)


_SCORINGCONFIGURATION = _descriptor.Descriptor(
  name='ScoringConfiguration',
  full_name='ScoringConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='method', full_name='ScoringConfiguration.method', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folds', full_name='ScoringConfiguration.folds', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='train_test_ratio', full_name='ScoringConfiguration.train_test_ratio', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shuffle', full_name='ScoringConfiguration.shuffle', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='random_seed', full_name='ScoringConfiguration.random_seed', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stratified', full_name='ScoringConfiguration.stratified', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=143,
  serialized_end=280,
)


_SCORE = _descriptor.Descriptor(
  name='Score',
  full_name='Score',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metric', full_name='Score.metric', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fold', full_name='Score.fold', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Score.value', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='random_seed', full_name='Score.random_seed', index=3,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='normalized', full_name='Score.normalized', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=283,
  serialized_end=419,
)


_PROGRESS = _descriptor.Descriptor(
  name='Progress',
  full_name='Progress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='Progress.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='Progress.status', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='Progress.start', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='Progress.end', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=422,
  serialized_end=563,
)


_SEARCHSOLUTIONSREQUEST = _descriptor.Descriptor(
  name='SearchSolutionsRequest',
  full_name='SearchSolutionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_agent', full_name='SearchSolutionsRequest.user_agent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='SearchSolutionsRequest.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_bound_search', full_name='SearchSolutionsRequest.time_bound_search', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='SearchSolutionsRequest.priority', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_value_types', full_name='SearchSolutionsRequest.allowed_value_types', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='problem', full_name='SearchSolutionsRequest.problem', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='template', full_name='SearchSolutionsRequest.template', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='SearchSolutionsRequest.inputs', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_bound_run', full_name='SearchSolutionsRequest.time_bound_run', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rank_solutions_limit', full_name='SearchSolutionsRequest.rank_solutions_limit', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='random_seed', full_name='SearchSolutionsRequest.random_seed', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_default_values_for_free_hyperparams', full_name='SearchSolutionsRequest.use_default_values_for_free_hyperparams', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='search_features', full_name='SearchSolutionsRequest.search_features', index=12,
      number=13, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=566,
  serialized_end=952,
)


_SEARCHSOLUTIONSRESPONSE = _descriptor.Descriptor(
  name='SearchSolutionsResponse',
  full_name='SearchSolutionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='search_id', full_name='SearchSolutionsResponse.search_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=954,
  serialized_end=998,
)


_ENDSEARCHSOLUTIONSREQUEST = _descriptor.Descriptor(
  name='EndSearchSolutionsRequest',
  full_name='EndSearchSolutionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='search_id', full_name='EndSearchSolutionsRequest.search_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1000,
  serialized_end=1046,
)


_ENDSEARCHSOLUTIONSRESPONSE = _descriptor.Descriptor(
  name='EndSearchSolutionsResponse',
  full_name='EndSearchSolutionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1048,
  serialized_end=1076,
)


_STOPSEARCHSOLUTIONSREQUEST = _descriptor.Descriptor(
  name='StopSearchSolutionsRequest',
  full_name='StopSearchSolutionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='search_id', full_name='StopSearchSolutionsRequest.search_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1078,
  serialized_end=1125,
)


_STOPSEARCHSOLUTIONSRESPONSE = _descriptor.Descriptor(
  name='StopSearchSolutionsResponse',
  full_name='StopSearchSolutionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1127,
  serialized_end=1156,
)


_SOLUTIONSEARCHSCORE = _descriptor.Descriptor(
  name='SolutionSearchScore',
  full_name='SolutionSearchScore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoring_configuration', full_name='SolutionSearchScore.scoring_configuration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scores', full_name='SolutionSearchScore.scores', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1158,
  serialized_end=1257,
)


_GETSEARCHSOLUTIONSRESULTSREQUEST = _descriptor.Descriptor(
  name='GetSearchSolutionsResultsRequest',
  full_name='GetSearchSolutionsResultsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='search_id', full_name='GetSearchSolutionsResultsRequest.search_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1259,
  serialized_end=1312,
)


_GETSEARCHSOLUTIONSRESULTSRESPONSE = _descriptor.Descriptor(
  name='GetSearchSolutionsResultsResponse',
  full_name='GetSearchSolutionsResultsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='progress', full_name='GetSearchSolutionsResultsResponse.progress', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='done_ticks', full_name='GetSearchSolutionsResultsResponse.done_ticks', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='all_ticks', full_name='GetSearchSolutionsResultsResponse.all_ticks', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='solution_id', full_name='GetSearchSolutionsResultsResponse.solution_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internal_score', full_name='GetSearchSolutionsResultsResponse.internal_score', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scores', full_name='GetSearchSolutionsResultsResponse.scores', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1315,
  serialized_end=1501,
)


_DESCRIBESOLUTIONREQUEST = _descriptor.Descriptor(
  name='DescribeSolutionRequest',
  full_name='DescribeSolutionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='solution_id', full_name='DescribeSolutionRequest.solution_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1503,
  serialized_end=1549,
)


_PRIMITIVESTEPDESCRIPTION_HYPERPARAMSENTRY = _descriptor.Descriptor(
  name='HyperparamsEntry',
  full_name='PrimitiveStepDescription.HyperparamsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='PrimitiveStepDescription.HyperparamsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='PrimitiveStepDescription.HyperparamsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1645,
  serialized_end=1703,
)

_PRIMITIVESTEPDESCRIPTION = _descriptor.Descriptor(
  name='PrimitiveStepDescription',
  full_name='PrimitiveStepDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hyperparams', full_name='PrimitiveStepDescription.hyperparams', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PRIMITIVESTEPDESCRIPTION_HYPERPARAMSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1552,
  serialized_end=1703,
)


_SUBPIPELINESTEPDESCRIPTION = _descriptor.Descriptor(
  name='SubpipelineStepDescription',
  full_name='SubpipelineStepDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steps', full_name='SubpipelineStepDescription.steps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1705,
  serialized_end=1766,
)


_STEPDESCRIPTION = _descriptor.Descriptor(
  name='StepDescription',
  full_name='StepDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='primitive', full_name='StepDescription.primitive', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='StepDescription.pipeline', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='step', full_name='StepDescription.step',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1768,
  serialized_end=1890,
)


_DESCRIBESOLUTIONRESPONSE = _descriptor.Descriptor(
  name='DescribeSolutionResponse',
  full_name='DescribeSolutionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='DescribeSolutionResponse.pipeline', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steps', full_name='DescribeSolutionResponse.steps', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1892,
  serialized_end=1991,
)


_STEPPROGRESS = _descriptor.Descriptor(
  name='StepProgress',
  full_name='StepProgress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='progress', full_name='StepProgress.progress', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steps', full_name='StepProgress.steps', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1993,
  serialized_end=2066,
)


_SOLUTIONRUNUSER = _descriptor.Descriptor(
  name='SolutionRunUser',
  full_name='SolutionRunUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='SolutionRunUser.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chosen', full_name='SolutionRunUser.chosen', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='SolutionRunUser.reason', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2068,
  serialized_end=2129,
)


_SCORESOLUTIONREQUEST = _descriptor.Descriptor(
  name='ScoreSolutionRequest',
  full_name='ScoreSolutionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='solution_id', full_name='ScoreSolutionRequest.solution_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='ScoreSolutionRequest.inputs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='performance_metrics', full_name='ScoreSolutionRequest.performance_metrics', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='users', full_name='ScoreSolutionRequest.users', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configuration', full_name='ScoreSolutionRequest.configuration', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2132,
  serialized_end=2334,
)


_SCORESOLUTIONRESPONSE = _descriptor.Descriptor(
  name='ScoreSolutionResponse',
  full_name='ScoreSolutionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='ScoreSolutionResponse.request_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2336,
  serialized_end=2379,
)


_GETSCORESOLUTIONRESULTSREQUEST = _descriptor.Descriptor(
  name='GetScoreSolutionResultsRequest',
  full_name='GetScoreSolutionResultsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='GetScoreSolutionResultsRequest.request_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2381,
  serialized_end=2433,
)


_GETSCORESOLUTIONRESULTSRESPONSE = _descriptor.Descriptor(
  name='GetScoreSolutionResultsResponse',
  full_name='GetScoreSolutionResultsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='progress', full_name='GetScoreSolutionResultsResponse.progress', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scores', full_name='GetScoreSolutionResultsResponse.scores', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2435,
  serialized_end=2521,
)


_FITSOLUTIONREQUEST = _descriptor.Descriptor(
  name='FitSolutionRequest',
  full_name='FitSolutionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='solution_id', full_name='FitSolutionRequest.solution_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='FitSolutionRequest.inputs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expose_outputs', full_name='FitSolutionRequest.expose_outputs', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expose_value_types', full_name='FitSolutionRequest.expose_value_types', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='users', full_name='FitSolutionRequest.users', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='random_seed', full_name='FitSolutionRequest.random_seed', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2524,
  serialized_end=2695,
)


_FITSOLUTIONRESPONSE = _descriptor.Descriptor(
  name='FitSolutionResponse',
  full_name='FitSolutionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='FitSolutionResponse.request_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2697,
  serialized_end=2738,
)


_GETFITSOLUTIONRESULTSREQUEST = _descriptor.Descriptor(
  name='GetFitSolutionResultsRequest',
  full_name='GetFitSolutionResultsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='GetFitSolutionResultsRequest.request_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2740,
  serialized_end=2790,
)


_GETFITSOLUTIONRESULTSRESPONSE_EXPOSEDOUTPUTSENTRY = _descriptor.Descriptor(
  name='ExposedOutputsEntry',
  full_name='GetFitSolutionResultsResponse.ExposedOutputsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='GetFitSolutionResultsResponse.ExposedOutputsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='GetFitSolutionResultsResponse.ExposedOutputsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2990,
  serialized_end=3051,
)

_GETFITSOLUTIONRESULTSRESPONSE = _descriptor.Descriptor(
  name='GetFitSolutionResultsResponse',
  full_name='GetFitSolutionResultsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='progress', full_name='GetFitSolutionResultsResponse.progress', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steps', full_name='GetFitSolutionResultsResponse.steps', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exposed_outputs', full_name='GetFitSolutionResultsResponse.exposed_outputs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fitted_solution_id', full_name='GetFitSolutionResultsResponse.fitted_solution_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETFITSOLUTIONRESULTSRESPONSE_EXPOSEDOUTPUTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2793,
  serialized_end=3051,
)


_PRODUCESOLUTIONREQUEST = _descriptor.Descriptor(
  name='ProduceSolutionRequest',
  full_name='ProduceSolutionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fitted_solution_id', full_name='ProduceSolutionRequest.fitted_solution_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='ProduceSolutionRequest.inputs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expose_outputs', full_name='ProduceSolutionRequest.expose_outputs', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expose_value_types', full_name='ProduceSolutionRequest.expose_value_types', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='users', full_name='ProduceSolutionRequest.users', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3054,
  serialized_end=3215,
)


_PRODUCESOLUTIONRESPONSE = _descriptor.Descriptor(
  name='ProduceSolutionResponse',
  full_name='ProduceSolutionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='ProduceSolutionResponse.request_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3217,
  serialized_end=3262,
)


_GETPRODUCESOLUTIONRESULTSREQUEST = _descriptor.Descriptor(
  name='GetProduceSolutionResultsRequest',
  full_name='GetProduceSolutionResultsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='GetProduceSolutionResultsRequest.request_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3264,
  serialized_end=3318,
)


_GETPRODUCESOLUTIONRESULTSRESPONSE_EXPOSEDOUTPUTSENTRY = _descriptor.Descriptor(
  name='ExposedOutputsEntry',
  full_name='GetProduceSolutionResultsResponse.ExposedOutputsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='GetProduceSolutionResultsResponse.ExposedOutputsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='GetProduceSolutionResultsResponse.ExposedOutputsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2990,
  serialized_end=3051,
)

_GETPRODUCESOLUTIONRESULTSRESPONSE = _descriptor.Descriptor(
  name='GetProduceSolutionResultsResponse',
  full_name='GetProduceSolutionResultsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='progress', full_name='GetProduceSolutionResultsResponse.progress', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steps', full_name='GetProduceSolutionResultsResponse.steps', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exposed_outputs', full_name='GetProduceSolutionResultsResponse.exposed_outputs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETPRODUCESOLUTIONRESULTSRESPONSE_EXPOSEDOUTPUTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3321,
  serialized_end=3559,
)


_SOLUTIONEXPORTREQUEST = _descriptor.Descriptor(
  name='SolutionExportRequest',
  full_name='SolutionExportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='solution_id', full_name='SolutionExportRequest.solution_id', index=0,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rank', full_name='SolutionExportRequest.rank', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3561,
  serialized_end=3619,
)


_SOLUTIONEXPORTRESPONSE = _descriptor.Descriptor(
  name='SolutionExportResponse',
  full_name='SolutionExportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3621,
  serialized_end=3645,
)


_DATAAVAILABLEREQUEST = _descriptor.Descriptor(
  name='DataAvailableRequest',
  full_name='DataAvailableRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_agent', full_name='DataAvailableRequest.user_agent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='DataAvailableRequest.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_bound', full_name='DataAvailableRequest.time_bound', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='DataAvailableRequest.priority', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='DataAvailableRequest.data', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3647,
  serialized_end=3766,
)


_DATAAVAILABLERESPONSE = _descriptor.Descriptor(
  name='DataAvailableResponse',
  full_name='DataAvailableResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3768,
  serialized_end=3791,
)


_SPLITDATAREQUEST = _descriptor.Descriptor(
  name='SplitDataRequest',
  full_name='SplitDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input', full_name='SplitDataRequest.input', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoring_configuration', full_name='SplitDataRequest.scoring_configuration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_value_types', full_name='SplitDataRequest.allowed_value_types', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='problem', full_name='SplitDataRequest.problem', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3794,
  serialized_end=3956,
)


_SPLITDATARESPONSE = _descriptor.Descriptor(
  name='SplitDataResponse',
  full_name='SplitDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='train_output', full_name='SplitDataResponse.train_output', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='test_output', full_name='SplitDataResponse.test_output', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score_output', full_name='SplitDataResponse.score_output', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3958,
  serialized_end=4066,
)


_SCOREPREDICTIONSREQUEST = _descriptor.Descriptor(
  name='ScorePredictionsRequest',
  full_name='ScorePredictionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='predictions', full_name='ScorePredictionsRequest.predictions', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score_input', full_name='ScorePredictionsRequest.score_input', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='problem', full_name='ScorePredictionsRequest.problem', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric', full_name='ScorePredictionsRequest.metric', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4069,
  serialized_end=4233,
)


_SCOREPREDICTIONSRESPONSE = _descriptor.Descriptor(
  name='ScorePredictionsResponse',
  full_name='ScorePredictionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scores', full_name='ScorePredictionsResponse.scores', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4235,
  serialized_end=4285,
)


_SAVESOLUTIONREQUEST = _descriptor.Descriptor(
  name='SaveSolutionRequest',
  full_name='SaveSolutionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='solution_id', full_name='SaveSolutionRequest.solution_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4287,
  serialized_end=4329,
)


_SAVESOLUTIONRESPONSE = _descriptor.Descriptor(
  name='SaveSolutionResponse',
  full_name='SaveSolutionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='solution_uri', full_name='SaveSolutionResponse.solution_uri', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4331,
  serialized_end=4375,
)


_LOADSOLUTIONREQUEST = _descriptor.Descriptor(
  name='LoadSolutionRequest',
  full_name='LoadSolutionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='solution_uri', full_name='LoadSolutionRequest.solution_uri', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4377,
  serialized_end=4420,
)


_LOADSOLUTIONRESPONSE = _descriptor.Descriptor(
  name='LoadSolutionResponse',
  full_name='LoadSolutionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='solution_id', full_name='LoadSolutionResponse.solution_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4422,
  serialized_end=4465,
)


_SAVEFITTEDSOLUTIONREQUEST = _descriptor.Descriptor(
  name='SaveFittedSolutionRequest',
  full_name='SaveFittedSolutionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fitted_solution_id', full_name='SaveFittedSolutionRequest.fitted_solution_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4467,
  serialized_end=4522,
)


_SAVEFITTEDSOLUTIONRESPONSE = _descriptor.Descriptor(
  name='SaveFittedSolutionResponse',
  full_name='SaveFittedSolutionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fitted_solution_uri', full_name='SaveFittedSolutionResponse.fitted_solution_uri', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4524,
  serialized_end=4581,
)


_LOADFITTEDSOLUTIONREQUEST = _descriptor.Descriptor(
  name='LoadFittedSolutionRequest',
  full_name='LoadFittedSolutionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fitted_solution_uri', full_name='LoadFittedSolutionRequest.fitted_solution_uri', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4583,
  serialized_end=4639,
)


_LOADFITTEDSOLUTIONRESPONSE = _descriptor.Descriptor(
  name='LoadFittedSolutionResponse',
  full_name='LoadFittedSolutionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fitted_solution_id', full_name='LoadFittedSolutionResponse.fitted_solution_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4641,
  serialized_end=4697,
)


_LISTPRIMITIVESREQUEST = _descriptor.Descriptor(
  name='ListPrimitivesRequest',
  full_name='ListPrimitivesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4699,
  serialized_end=4722,
)


_LISTPRIMITIVESRESPONSE = _descriptor.Descriptor(
  name='ListPrimitivesResponse',
  full_name='ListPrimitivesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='primitives', full_name='ListPrimitivesResponse.primitives', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4724,
  serialized_end=4780,
)


_HELLOREQUEST = _descriptor.Descriptor(
  name='HelloRequest',
  full_name='HelloRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4782,
  serialized_end=4796,
)


_HELLORESPONSE = _descriptor.Descriptor(
  name='HelloResponse',
  full_name='HelloResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_agent', full_name='HelloResponse.user_agent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='HelloResponse.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_value_types', full_name='HelloResponse.allowed_value_types', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supported_extensions', full_name='HelloResponse.supported_extensions', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supported_task_keywords', full_name='HelloResponse.supported_task_keywords', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supported_performance_metrics', full_name='HelloResponse.supported_performance_metrics', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supported_evaluation_methods', full_name='HelloResponse.supported_evaluation_methods', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supported_search_features', full_name='HelloResponse.supported_search_features', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4799,
  serialized_end=5055,
)

_SCORE.fields_by_name['metric'].message_type = problem__pb2._PROBLEMPERFORMANCEMETRIC
_SCORE.fields_by_name['value'].message_type = value__pb2._VALUE
_SCORE.fields_by_name['normalized'].message_type = value__pb2._VALUE
_PROGRESS.fields_by_name['state'].enum_type = _PROGRESSSTATE
_PROGRESS.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PROGRESS.fields_by_name['end'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SEARCHSOLUTIONSREQUEST.fields_by_name['problem'].message_type = problem__pb2._PROBLEMDESCRIPTION
_SEARCHSOLUTIONSREQUEST.fields_by_name['template'].message_type = pipeline__pb2._PIPELINEDESCRIPTION
_SEARCHSOLUTIONSREQUEST.fields_by_name['inputs'].message_type = value__pb2._VALUE
_SOLUTIONSEARCHSCORE.fields_by_name['scoring_configuration'].message_type = _SCORINGCONFIGURATION
_SOLUTIONSEARCHSCORE.fields_by_name['scores'].message_type = _SCORE
_GETSEARCHSOLUTIONSRESULTSRESPONSE.fields_by_name['progress'].message_type = _PROGRESS
_GETSEARCHSOLUTIONSRESULTSRESPONSE.fields_by_name['scores'].message_type = _SOLUTIONSEARCHSCORE
_PRIMITIVESTEPDESCRIPTION_HYPERPARAMSENTRY.fields_by_name['value'].message_type = value__pb2._VALUE
_PRIMITIVESTEPDESCRIPTION_HYPERPARAMSENTRY.containing_type = _PRIMITIVESTEPDESCRIPTION
_PRIMITIVESTEPDESCRIPTION.fields_by_name['hyperparams'].message_type = _PRIMITIVESTEPDESCRIPTION_HYPERPARAMSENTRY
_SUBPIPELINESTEPDESCRIPTION.fields_by_name['steps'].message_type = _STEPDESCRIPTION
_STEPDESCRIPTION.fields_by_name['primitive'].message_type = _PRIMITIVESTEPDESCRIPTION
_STEPDESCRIPTION.fields_by_name['pipeline'].message_type = _SUBPIPELINESTEPDESCRIPTION
_STEPDESCRIPTION.oneofs_by_name['step'].fields.append(
  _STEPDESCRIPTION.fields_by_name['primitive'])
_STEPDESCRIPTION.fields_by_name['primitive'].containing_oneof = _STEPDESCRIPTION.oneofs_by_name['step']
_STEPDESCRIPTION.oneofs_by_name['step'].fields.append(
  _STEPDESCRIPTION.fields_by_name['pipeline'])
_STEPDESCRIPTION.fields_by_name['pipeline'].containing_oneof = _STEPDESCRIPTION.oneofs_by_name['step']
_DESCRIBESOLUTIONRESPONSE.fields_by_name['pipeline'].message_type = pipeline__pb2._PIPELINEDESCRIPTION
_DESCRIBESOLUTIONRESPONSE.fields_by_name['steps'].message_type = _STEPDESCRIPTION
_STEPPROGRESS.fields_by_name['progress'].message_type = _PROGRESS
_STEPPROGRESS.fields_by_name['steps'].message_type = _STEPPROGRESS
_SCORESOLUTIONREQUEST.fields_by_name['inputs'].message_type = value__pb2._VALUE
_SCORESOLUTIONREQUEST.fields_by_name['performance_metrics'].message_type = problem__pb2._PROBLEMPERFORMANCEMETRIC
_SCORESOLUTIONREQUEST.fields_by_name['users'].message_type = _SOLUTIONRUNUSER
_SCORESOLUTIONREQUEST.fields_by_name['configuration'].message_type = _SCORINGCONFIGURATION
_GETSCORESOLUTIONRESULTSRESPONSE.fields_by_name['progress'].message_type = _PROGRESS
_GETSCORESOLUTIONRESULTSRESPONSE.fields_by_name['scores'].message_type = _SCORE
_FITSOLUTIONREQUEST.fields_by_name['inputs'].message_type = value__pb2._VALUE
_FITSOLUTIONREQUEST.fields_by_name['users'].message_type = _SOLUTIONRUNUSER
_GETFITSOLUTIONRESULTSRESPONSE_EXPOSEDOUTPUTSENTRY.fields_by_name['value'].message_type = value__pb2._VALUE
_GETFITSOLUTIONRESULTSRESPONSE_EXPOSEDOUTPUTSENTRY.containing_type = _GETFITSOLUTIONRESULTSRESPONSE
_GETFITSOLUTIONRESULTSRESPONSE.fields_by_name['progress'].message_type = _PROGRESS
_GETFITSOLUTIONRESULTSRESPONSE.fields_by_name['steps'].message_type = _STEPPROGRESS
_GETFITSOLUTIONRESULTSRESPONSE.fields_by_name['exposed_outputs'].message_type = _GETFITSOLUTIONRESULTSRESPONSE_EXPOSEDOUTPUTSENTRY
_PRODUCESOLUTIONREQUEST.fields_by_name['inputs'].message_type = value__pb2._VALUE
_PRODUCESOLUTIONREQUEST.fields_by_name['users'].message_type = _SOLUTIONRUNUSER
_GETPRODUCESOLUTIONRESULTSRESPONSE_EXPOSEDOUTPUTSENTRY.fields_by_name['value'].message_type = value__pb2._VALUE
_GETPRODUCESOLUTIONRESULTSRESPONSE_EXPOSEDOUTPUTSENTRY.containing_type = _GETPRODUCESOLUTIONRESULTSRESPONSE
_GETPRODUCESOLUTIONRESULTSRESPONSE.fields_by_name['progress'].message_type = _PROGRESS
_GETPRODUCESOLUTIONRESULTSRESPONSE.fields_by_name['steps'].message_type = _STEPPROGRESS
_GETPRODUCESOLUTIONRESULTSRESPONSE.fields_by_name['exposed_outputs'].message_type = _GETPRODUCESOLUTIONRESULTSRESPONSE_EXPOSEDOUTPUTSENTRY
_DATAAVAILABLEREQUEST.fields_by_name['data'].message_type = value__pb2._VALUE
_SPLITDATAREQUEST.fields_by_name['input'].message_type = value__pb2._VALUE
_SPLITDATAREQUEST.fields_by_name['scoring_configuration'].message_type = _SCORINGCONFIGURATION
_SPLITDATAREQUEST.fields_by_name['problem'].message_type = problem__pb2._PROBLEMDESCRIPTION
_SPLITDATARESPONSE.fields_by_name['train_output'].message_type = value__pb2._VALUE
_SPLITDATARESPONSE.fields_by_name['test_output'].message_type = value__pb2._VALUE
_SPLITDATARESPONSE.fields_by_name['score_output'].message_type = value__pb2._VALUE
_SCOREPREDICTIONSREQUEST.fields_by_name['predictions'].message_type = value__pb2._VALUE
_SCOREPREDICTIONSREQUEST.fields_by_name['score_input'].message_type = value__pb2._VALUE
_SCOREPREDICTIONSREQUEST.fields_by_name['problem'].message_type = problem__pb2._PROBLEMDESCRIPTION
_SCOREPREDICTIONSREQUEST.fields_by_name['metric'].message_type = problem__pb2._PROBLEMPERFORMANCEMETRIC
_SCOREPREDICTIONSRESPONSE.fields_by_name['scores'].message_type = _SCORE
_LISTPRIMITIVESRESPONSE.fields_by_name['primitives'].message_type = primitive__pb2._PRIMITIVE
DESCRIPTOR.message_types_by_name['ScoringConfiguration'] = _SCORINGCONFIGURATION
DESCRIPTOR.message_types_by_name['Score'] = _SCORE
DESCRIPTOR.message_types_by_name['Progress'] = _PROGRESS
DESCRIPTOR.message_types_by_name['SearchSolutionsRequest'] = _SEARCHSOLUTIONSREQUEST
DESCRIPTOR.message_types_by_name['SearchSolutionsResponse'] = _SEARCHSOLUTIONSRESPONSE
DESCRIPTOR.message_types_by_name['EndSearchSolutionsRequest'] = _ENDSEARCHSOLUTIONSREQUEST
DESCRIPTOR.message_types_by_name['EndSearchSolutionsResponse'] = _ENDSEARCHSOLUTIONSRESPONSE
DESCRIPTOR.message_types_by_name['StopSearchSolutionsRequest'] = _STOPSEARCHSOLUTIONSREQUEST
DESCRIPTOR.message_types_by_name['StopSearchSolutionsResponse'] = _STOPSEARCHSOLUTIONSRESPONSE
DESCRIPTOR.message_types_by_name['SolutionSearchScore'] = _SOLUTIONSEARCHSCORE
DESCRIPTOR.message_types_by_name['GetSearchSolutionsResultsRequest'] = _GETSEARCHSOLUTIONSRESULTSREQUEST
DESCRIPTOR.message_types_by_name['GetSearchSolutionsResultsResponse'] = _GETSEARCHSOLUTIONSRESULTSRESPONSE
DESCRIPTOR.message_types_by_name['DescribeSolutionRequest'] = _DESCRIBESOLUTIONREQUEST
DESCRIPTOR.message_types_by_name['PrimitiveStepDescription'] = _PRIMITIVESTEPDESCRIPTION
DESCRIPTOR.message_types_by_name['SubpipelineStepDescription'] = _SUBPIPELINESTEPDESCRIPTION
DESCRIPTOR.message_types_by_name['StepDescription'] = _STEPDESCRIPTION
DESCRIPTOR.message_types_by_name['DescribeSolutionResponse'] = _DESCRIBESOLUTIONRESPONSE
DESCRIPTOR.message_types_by_name['StepProgress'] = _STEPPROGRESS
DESCRIPTOR.message_types_by_name['SolutionRunUser'] = _SOLUTIONRUNUSER
DESCRIPTOR.message_types_by_name['ScoreSolutionRequest'] = _SCORESOLUTIONREQUEST
DESCRIPTOR.message_types_by_name['ScoreSolutionResponse'] = _SCORESOLUTIONRESPONSE
DESCRIPTOR.message_types_by_name['GetScoreSolutionResultsRequest'] = _GETSCORESOLUTIONRESULTSREQUEST
DESCRIPTOR.message_types_by_name['GetScoreSolutionResultsResponse'] = _GETSCORESOLUTIONRESULTSRESPONSE
DESCRIPTOR.message_types_by_name['FitSolutionRequest'] = _FITSOLUTIONREQUEST
DESCRIPTOR.message_types_by_name['FitSolutionResponse'] = _FITSOLUTIONRESPONSE
DESCRIPTOR.message_types_by_name['GetFitSolutionResultsRequest'] = _GETFITSOLUTIONRESULTSREQUEST
DESCRIPTOR.message_types_by_name['GetFitSolutionResultsResponse'] = _GETFITSOLUTIONRESULTSRESPONSE
DESCRIPTOR.message_types_by_name['ProduceSolutionRequest'] = _PRODUCESOLUTIONREQUEST
DESCRIPTOR.message_types_by_name['ProduceSolutionResponse'] = _PRODUCESOLUTIONRESPONSE
DESCRIPTOR.message_types_by_name['GetProduceSolutionResultsRequest'] = _GETPRODUCESOLUTIONRESULTSREQUEST
DESCRIPTOR.message_types_by_name['GetProduceSolutionResultsResponse'] = _GETPRODUCESOLUTIONRESULTSRESPONSE
DESCRIPTOR.message_types_by_name['SolutionExportRequest'] = _SOLUTIONEXPORTREQUEST
DESCRIPTOR.message_types_by_name['SolutionExportResponse'] = _SOLUTIONEXPORTRESPONSE
DESCRIPTOR.message_types_by_name['DataAvailableRequest'] = _DATAAVAILABLEREQUEST
DESCRIPTOR.message_types_by_name['DataAvailableResponse'] = _DATAAVAILABLERESPONSE
DESCRIPTOR.message_types_by_name['SplitDataRequest'] = _SPLITDATAREQUEST
DESCRIPTOR.message_types_by_name['SplitDataResponse'] = _SPLITDATARESPONSE
DESCRIPTOR.message_types_by_name['ScorePredictionsRequest'] = _SCOREPREDICTIONSREQUEST
DESCRIPTOR.message_types_by_name['ScorePredictionsResponse'] = _SCOREPREDICTIONSRESPONSE
DESCRIPTOR.message_types_by_name['SaveSolutionRequest'] = _SAVESOLUTIONREQUEST
DESCRIPTOR.message_types_by_name['SaveSolutionResponse'] = _SAVESOLUTIONRESPONSE
DESCRIPTOR.message_types_by_name['LoadSolutionRequest'] = _LOADSOLUTIONREQUEST
DESCRIPTOR.message_types_by_name['LoadSolutionResponse'] = _LOADSOLUTIONRESPONSE
DESCRIPTOR.message_types_by_name['SaveFittedSolutionRequest'] = _SAVEFITTEDSOLUTIONREQUEST
DESCRIPTOR.message_types_by_name['SaveFittedSolutionResponse'] = _SAVEFITTEDSOLUTIONRESPONSE
DESCRIPTOR.message_types_by_name['LoadFittedSolutionRequest'] = _LOADFITTEDSOLUTIONREQUEST
DESCRIPTOR.message_types_by_name['LoadFittedSolutionResponse'] = _LOADFITTEDSOLUTIONRESPONSE
DESCRIPTOR.message_types_by_name['ListPrimitivesRequest'] = _LISTPRIMITIVESREQUEST
DESCRIPTOR.message_types_by_name['ListPrimitivesResponse'] = _LISTPRIMITIVESRESPONSE
DESCRIPTOR.message_types_by_name['HelloRequest'] = _HELLOREQUEST
DESCRIPTOR.message_types_by_name['HelloResponse'] = _HELLORESPONSE
DESCRIPTOR.enum_types_by_name['ProgressState'] = _PROGRESSSTATE
DESCRIPTOR.extensions_by_name['protocol_version'] = protocol_version
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ScoringConfiguration = _reflection.GeneratedProtocolMessageType('ScoringConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _SCORINGCONFIGURATION,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:ScoringConfiguration)
  })
_sym_db.RegisterMessage(ScoringConfiguration)

Score = _reflection.GeneratedProtocolMessageType('Score', (_message.Message,), {
  'DESCRIPTOR' : _SCORE,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:Score)
  })
_sym_db.RegisterMessage(Score)

Progress = _reflection.GeneratedProtocolMessageType('Progress', (_message.Message,), {
  'DESCRIPTOR' : _PROGRESS,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:Progress)
  })
_sym_db.RegisterMessage(Progress)

SearchSolutionsRequest = _reflection.GeneratedProtocolMessageType('SearchSolutionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHSOLUTIONSREQUEST,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:SearchSolutionsRequest)
  })
_sym_db.RegisterMessage(SearchSolutionsRequest)

SearchSolutionsResponse = _reflection.GeneratedProtocolMessageType('SearchSolutionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHSOLUTIONSRESPONSE,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:SearchSolutionsResponse)
  })
_sym_db.RegisterMessage(SearchSolutionsResponse)

EndSearchSolutionsRequest = _reflection.GeneratedProtocolMessageType('EndSearchSolutionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENDSEARCHSOLUTIONSREQUEST,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:EndSearchSolutionsRequest)
  })
_sym_db.RegisterMessage(EndSearchSolutionsRequest)

EndSearchSolutionsResponse = _reflection.GeneratedProtocolMessageType('EndSearchSolutionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _ENDSEARCHSOLUTIONSRESPONSE,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:EndSearchSolutionsResponse)
  })
_sym_db.RegisterMessage(EndSearchSolutionsResponse)

StopSearchSolutionsRequest = _reflection.GeneratedProtocolMessageType('StopSearchSolutionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPSEARCHSOLUTIONSREQUEST,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:StopSearchSolutionsRequest)
  })
_sym_db.RegisterMessage(StopSearchSolutionsRequest)

StopSearchSolutionsResponse = _reflection.GeneratedProtocolMessageType('StopSearchSolutionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _STOPSEARCHSOLUTIONSRESPONSE,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:StopSearchSolutionsResponse)
  })
_sym_db.RegisterMessage(StopSearchSolutionsResponse)

SolutionSearchScore = _reflection.GeneratedProtocolMessageType('SolutionSearchScore', (_message.Message,), {
  'DESCRIPTOR' : _SOLUTIONSEARCHSCORE,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:SolutionSearchScore)
  })
_sym_db.RegisterMessage(SolutionSearchScore)

GetSearchSolutionsResultsRequest = _reflection.GeneratedProtocolMessageType('GetSearchSolutionsResultsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSEARCHSOLUTIONSRESULTSREQUEST,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:GetSearchSolutionsResultsRequest)
  })
_sym_db.RegisterMessage(GetSearchSolutionsResultsRequest)

GetSearchSolutionsResultsResponse = _reflection.GeneratedProtocolMessageType('GetSearchSolutionsResultsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSEARCHSOLUTIONSRESULTSRESPONSE,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:GetSearchSolutionsResultsResponse)
  })
_sym_db.RegisterMessage(GetSearchSolutionsResultsResponse)

DescribeSolutionRequest = _reflection.GeneratedProtocolMessageType('DescribeSolutionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESOLUTIONREQUEST,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:DescribeSolutionRequest)
  })
_sym_db.RegisterMessage(DescribeSolutionRequest)

PrimitiveStepDescription = _reflection.GeneratedProtocolMessageType('PrimitiveStepDescription', (_message.Message,), {

  'HyperparamsEntry' : _reflection.GeneratedProtocolMessageType('HyperparamsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PRIMITIVESTEPDESCRIPTION_HYPERPARAMSENTRY,
    '__module__' : 'core_pb2'
    # @@protoc_insertion_point(class_scope:PrimitiveStepDescription.HyperparamsEntry)
    })
  ,
  'DESCRIPTOR' : _PRIMITIVESTEPDESCRIPTION,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:PrimitiveStepDescription)
  })
_sym_db.RegisterMessage(PrimitiveStepDescription)
_sym_db.RegisterMessage(PrimitiveStepDescription.HyperparamsEntry)

SubpipelineStepDescription = _reflection.GeneratedProtocolMessageType('SubpipelineStepDescription', (_message.Message,), {
  'DESCRIPTOR' : _SUBPIPELINESTEPDESCRIPTION,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:SubpipelineStepDescription)
  })
_sym_db.RegisterMessage(SubpipelineStepDescription)

StepDescription = _reflection.GeneratedProtocolMessageType('StepDescription', (_message.Message,), {
  'DESCRIPTOR' : _STEPDESCRIPTION,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:StepDescription)
  })
_sym_db.RegisterMessage(StepDescription)

DescribeSolutionResponse = _reflection.GeneratedProtocolMessageType('DescribeSolutionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESOLUTIONRESPONSE,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:DescribeSolutionResponse)
  })
_sym_db.RegisterMessage(DescribeSolutionResponse)

StepProgress = _reflection.GeneratedProtocolMessageType('StepProgress', (_message.Message,), {
  'DESCRIPTOR' : _STEPPROGRESS,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:StepProgress)
  })
_sym_db.RegisterMessage(StepProgress)

SolutionRunUser = _reflection.GeneratedProtocolMessageType('SolutionRunUser', (_message.Message,), {
  'DESCRIPTOR' : _SOLUTIONRUNUSER,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:SolutionRunUser)
  })
_sym_db.RegisterMessage(SolutionRunUser)

ScoreSolutionRequest = _reflection.GeneratedProtocolMessageType('ScoreSolutionRequest', (_message.Message,), {
  'DESCRIPTOR' : _SCORESOLUTIONREQUEST,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:ScoreSolutionRequest)
  })
_sym_db.RegisterMessage(ScoreSolutionRequest)

ScoreSolutionResponse = _reflection.GeneratedProtocolMessageType('ScoreSolutionResponse', (_message.Message,), {
  'DESCRIPTOR' : _SCORESOLUTIONRESPONSE,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:ScoreSolutionResponse)
  })
_sym_db.RegisterMessage(ScoreSolutionResponse)

GetScoreSolutionResultsRequest = _reflection.GeneratedProtocolMessageType('GetScoreSolutionResultsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSCORESOLUTIONRESULTSREQUEST,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:GetScoreSolutionResultsRequest)
  })
_sym_db.RegisterMessage(GetScoreSolutionResultsRequest)

GetScoreSolutionResultsResponse = _reflection.GeneratedProtocolMessageType('GetScoreSolutionResultsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSCORESOLUTIONRESULTSRESPONSE,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:GetScoreSolutionResultsResponse)
  })
_sym_db.RegisterMessage(GetScoreSolutionResultsResponse)

FitSolutionRequest = _reflection.GeneratedProtocolMessageType('FitSolutionRequest', (_message.Message,), {
  'DESCRIPTOR' : _FITSOLUTIONREQUEST,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:FitSolutionRequest)
  })
_sym_db.RegisterMessage(FitSolutionRequest)

FitSolutionResponse = _reflection.GeneratedProtocolMessageType('FitSolutionResponse', (_message.Message,), {
  'DESCRIPTOR' : _FITSOLUTIONRESPONSE,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:FitSolutionResponse)
  })
_sym_db.RegisterMessage(FitSolutionResponse)

GetFitSolutionResultsRequest = _reflection.GeneratedProtocolMessageType('GetFitSolutionResultsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFITSOLUTIONRESULTSREQUEST,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:GetFitSolutionResultsRequest)
  })
_sym_db.RegisterMessage(GetFitSolutionResultsRequest)

GetFitSolutionResultsResponse = _reflection.GeneratedProtocolMessageType('GetFitSolutionResultsResponse', (_message.Message,), {

  'ExposedOutputsEntry' : _reflection.GeneratedProtocolMessageType('ExposedOutputsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETFITSOLUTIONRESULTSRESPONSE_EXPOSEDOUTPUTSENTRY,
    '__module__' : 'core_pb2'
    # @@protoc_insertion_point(class_scope:GetFitSolutionResultsResponse.ExposedOutputsEntry)
    })
  ,
  'DESCRIPTOR' : _GETFITSOLUTIONRESULTSRESPONSE,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:GetFitSolutionResultsResponse)
  })
_sym_db.RegisterMessage(GetFitSolutionResultsResponse)
_sym_db.RegisterMessage(GetFitSolutionResultsResponse.ExposedOutputsEntry)

ProduceSolutionRequest = _reflection.GeneratedProtocolMessageType('ProduceSolutionRequest', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCESOLUTIONREQUEST,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:ProduceSolutionRequest)
  })
_sym_db.RegisterMessage(ProduceSolutionRequest)

ProduceSolutionResponse = _reflection.GeneratedProtocolMessageType('ProduceSolutionResponse', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCESOLUTIONRESPONSE,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:ProduceSolutionResponse)
  })
_sym_db.RegisterMessage(ProduceSolutionResponse)

GetProduceSolutionResultsRequest = _reflection.GeneratedProtocolMessageType('GetProduceSolutionResultsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPRODUCESOLUTIONRESULTSREQUEST,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:GetProduceSolutionResultsRequest)
  })
_sym_db.RegisterMessage(GetProduceSolutionResultsRequest)

GetProduceSolutionResultsResponse = _reflection.GeneratedProtocolMessageType('GetProduceSolutionResultsResponse', (_message.Message,), {

  'ExposedOutputsEntry' : _reflection.GeneratedProtocolMessageType('ExposedOutputsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETPRODUCESOLUTIONRESULTSRESPONSE_EXPOSEDOUTPUTSENTRY,
    '__module__' : 'core_pb2'
    # @@protoc_insertion_point(class_scope:GetProduceSolutionResultsResponse.ExposedOutputsEntry)
    })
  ,
  'DESCRIPTOR' : _GETPRODUCESOLUTIONRESULTSRESPONSE,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:GetProduceSolutionResultsResponse)
  })
_sym_db.RegisterMessage(GetProduceSolutionResultsResponse)
_sym_db.RegisterMessage(GetProduceSolutionResultsResponse.ExposedOutputsEntry)

SolutionExportRequest = _reflection.GeneratedProtocolMessageType('SolutionExportRequest', (_message.Message,), {
  'DESCRIPTOR' : _SOLUTIONEXPORTREQUEST,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:SolutionExportRequest)
  })
_sym_db.RegisterMessage(SolutionExportRequest)

SolutionExportResponse = _reflection.GeneratedProtocolMessageType('SolutionExportResponse', (_message.Message,), {
  'DESCRIPTOR' : _SOLUTIONEXPORTRESPONSE,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:SolutionExportResponse)
  })
_sym_db.RegisterMessage(SolutionExportResponse)

DataAvailableRequest = _reflection.GeneratedProtocolMessageType('DataAvailableRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATAAVAILABLEREQUEST,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:DataAvailableRequest)
  })
_sym_db.RegisterMessage(DataAvailableRequest)

DataAvailableResponse = _reflection.GeneratedProtocolMessageType('DataAvailableResponse', (_message.Message,), {
  'DESCRIPTOR' : _DATAAVAILABLERESPONSE,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:DataAvailableResponse)
  })
_sym_db.RegisterMessage(DataAvailableResponse)

SplitDataRequest = _reflection.GeneratedProtocolMessageType('SplitDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _SPLITDATAREQUEST,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:SplitDataRequest)
  })
_sym_db.RegisterMessage(SplitDataRequest)

SplitDataResponse = _reflection.GeneratedProtocolMessageType('SplitDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _SPLITDATARESPONSE,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:SplitDataResponse)
  })
_sym_db.RegisterMessage(SplitDataResponse)

ScorePredictionsRequest = _reflection.GeneratedProtocolMessageType('ScorePredictionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SCOREPREDICTIONSREQUEST,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:ScorePredictionsRequest)
  })
_sym_db.RegisterMessage(ScorePredictionsRequest)

ScorePredictionsResponse = _reflection.GeneratedProtocolMessageType('ScorePredictionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _SCOREPREDICTIONSRESPONSE,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:ScorePredictionsResponse)
  })
_sym_db.RegisterMessage(ScorePredictionsResponse)

SaveSolutionRequest = _reflection.GeneratedProtocolMessageType('SaveSolutionRequest', (_message.Message,), {
  'DESCRIPTOR' : _SAVESOLUTIONREQUEST,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:SaveSolutionRequest)
  })
_sym_db.RegisterMessage(SaveSolutionRequest)

SaveSolutionResponse = _reflection.GeneratedProtocolMessageType('SaveSolutionResponse', (_message.Message,), {
  'DESCRIPTOR' : _SAVESOLUTIONRESPONSE,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:SaveSolutionResponse)
  })
_sym_db.RegisterMessage(SaveSolutionResponse)

LoadSolutionRequest = _reflection.GeneratedProtocolMessageType('LoadSolutionRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOADSOLUTIONREQUEST,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:LoadSolutionRequest)
  })
_sym_db.RegisterMessage(LoadSolutionRequest)

LoadSolutionResponse = _reflection.GeneratedProtocolMessageType('LoadSolutionResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOADSOLUTIONRESPONSE,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:LoadSolutionResponse)
  })
_sym_db.RegisterMessage(LoadSolutionResponse)

SaveFittedSolutionRequest = _reflection.GeneratedProtocolMessageType('SaveFittedSolutionRequest', (_message.Message,), {
  'DESCRIPTOR' : _SAVEFITTEDSOLUTIONREQUEST,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:SaveFittedSolutionRequest)
  })
_sym_db.RegisterMessage(SaveFittedSolutionRequest)

SaveFittedSolutionResponse = _reflection.GeneratedProtocolMessageType('SaveFittedSolutionResponse', (_message.Message,), {
  'DESCRIPTOR' : _SAVEFITTEDSOLUTIONRESPONSE,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:SaveFittedSolutionResponse)
  })
_sym_db.RegisterMessage(SaveFittedSolutionResponse)

LoadFittedSolutionRequest = _reflection.GeneratedProtocolMessageType('LoadFittedSolutionRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOADFITTEDSOLUTIONREQUEST,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:LoadFittedSolutionRequest)
  })
_sym_db.RegisterMessage(LoadFittedSolutionRequest)

LoadFittedSolutionResponse = _reflection.GeneratedProtocolMessageType('LoadFittedSolutionResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOADFITTEDSOLUTIONRESPONSE,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:LoadFittedSolutionResponse)
  })
_sym_db.RegisterMessage(LoadFittedSolutionResponse)

ListPrimitivesRequest = _reflection.GeneratedProtocolMessageType('ListPrimitivesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPRIMITIVESREQUEST,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:ListPrimitivesRequest)
  })
_sym_db.RegisterMessage(ListPrimitivesRequest)

ListPrimitivesResponse = _reflection.GeneratedProtocolMessageType('ListPrimitivesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPRIMITIVESRESPONSE,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:ListPrimitivesResponse)
  })
_sym_db.RegisterMessage(ListPrimitivesResponse)

HelloRequest = _reflection.GeneratedProtocolMessageType('HelloRequest', (_message.Message,), {
  'DESCRIPTOR' : _HELLOREQUEST,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:HelloRequest)
  })
_sym_db.RegisterMessage(HelloRequest)

HelloResponse = _reflection.GeneratedProtocolMessageType('HelloResponse', (_message.Message,), {
  'DESCRIPTOR' : _HELLORESPONSE,
  '__module__' : 'core_pb2'
  # @@protoc_insertion_point(class_scope:HelloResponse)
  })
_sym_db.RegisterMessage(HelloResponse)

google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(protocol_version)

DESCRIPTOR._options = None
_PRIMITIVESTEPDESCRIPTION_HYPERPARAMSENTRY._options = None
_GETFITSOLUTIONRESULTSRESPONSE_EXPOSEDOUTPUTSENTRY._options = None
_GETPRODUCESOLUTIONRESULTSRESPONSE_EXPOSEDOUTPUTSENTRY._options = None

_CORE = _descriptor.ServiceDescriptor(
  name='Core',
  full_name='Core',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=5151,
  serialized_end=6730,
  methods=[
  _descriptor.MethodDescriptor(
    name='SearchSolutions',
    full_name='Core.SearchSolutions',
    index=0,
    containing_service=None,
    input_type=_SEARCHSOLUTIONSREQUEST,
    output_type=_SEARCHSOLUTIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSearchSolutionsResults',
    full_name='Core.GetSearchSolutionsResults',
    index=1,
    containing_service=None,
    input_type=_GETSEARCHSOLUTIONSRESULTSREQUEST,
    output_type=_GETSEARCHSOLUTIONSRESULTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EndSearchSolutions',
    full_name='Core.EndSearchSolutions',
    index=2,
    containing_service=None,
    input_type=_ENDSEARCHSOLUTIONSREQUEST,
    output_type=_ENDSEARCHSOLUTIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StopSearchSolutions',
    full_name='Core.StopSearchSolutions',
    index=3,
    containing_service=None,
    input_type=_STOPSEARCHSOLUTIONSREQUEST,
    output_type=_STOPSEARCHSOLUTIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeSolution',
    full_name='Core.DescribeSolution',
    index=4,
    containing_service=None,
    input_type=_DESCRIBESOLUTIONREQUEST,
    output_type=_DESCRIBESOLUTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ScoreSolution',
    full_name='Core.ScoreSolution',
    index=5,
    containing_service=None,
    input_type=_SCORESOLUTIONREQUEST,
    output_type=_SCORESOLUTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetScoreSolutionResults',
    full_name='Core.GetScoreSolutionResults',
    index=6,
    containing_service=None,
    input_type=_GETSCORESOLUTIONRESULTSREQUEST,
    output_type=_GETSCORESOLUTIONRESULTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FitSolution',
    full_name='Core.FitSolution',
    index=7,
    containing_service=None,
    input_type=_FITSOLUTIONREQUEST,
    output_type=_FITSOLUTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFitSolutionResults',
    full_name='Core.GetFitSolutionResults',
    index=8,
    containing_service=None,
    input_type=_GETFITSOLUTIONRESULTSREQUEST,
    output_type=_GETFITSOLUTIONRESULTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ProduceSolution',
    full_name='Core.ProduceSolution',
    index=9,
    containing_service=None,
    input_type=_PRODUCESOLUTIONREQUEST,
    output_type=_PRODUCESOLUTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetProduceSolutionResults',
    full_name='Core.GetProduceSolutionResults',
    index=10,
    containing_service=None,
    input_type=_GETPRODUCESOLUTIONRESULTSREQUEST,
    output_type=_GETPRODUCESOLUTIONRESULTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SolutionExport',
    full_name='Core.SolutionExport',
    index=11,
    containing_service=None,
    input_type=_SOLUTIONEXPORTREQUEST,
    output_type=_SOLUTIONEXPORTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DataAvailable',
    full_name='Core.DataAvailable',
    index=12,
    containing_service=None,
    input_type=_DATAAVAILABLEREQUEST,
    output_type=_DATAAVAILABLERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListPrimitives',
    full_name='Core.ListPrimitives',
    index=13,
    containing_service=None,
    input_type=_LISTPRIMITIVESREQUEST,
    output_type=_LISTPRIMITIVESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Hello',
    full_name='Core.Hello',
    index=14,
    containing_service=None,
    input_type=_HELLOREQUEST,
    output_type=_HELLORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SaveSolution',
    full_name='Core.SaveSolution',
    index=15,
    containing_service=None,
    input_type=_SAVESOLUTIONREQUEST,
    output_type=_SAVESOLUTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LoadSolution',
    full_name='Core.LoadSolution',
    index=16,
    containing_service=None,
    input_type=_LOADSOLUTIONREQUEST,
    output_type=_LOADSOLUTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SaveFittedSolution',
    full_name='Core.SaveFittedSolution',
    index=17,
    containing_service=None,
    input_type=_SAVEFITTEDSOLUTIONREQUEST,
    output_type=_SAVEFITTEDSOLUTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LoadFittedSolution',
    full_name='Core.LoadFittedSolution',
    index=18,
    containing_service=None,
    input_type=_LOADFITTEDSOLUTIONREQUEST,
    output_type=_LOADFITTEDSOLUTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SplitData',
    full_name='Core.SplitData',
    index=19,
    containing_service=None,
    input_type=_SPLITDATAREQUEST,
    output_type=_SPLITDATARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ScorePredictions',
    full_name='Core.ScorePredictions',
    index=20,
    containing_service=None,
    input_type=_SCOREPREDICTIONSREQUEST,
    output_type=_SCOREPREDICTIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CORE)

DESCRIPTOR.services_by_name['Core'] = _CORE

# @@protoc_insertion_point(module_scope)
